@@ -11,6 +11,11 @@
 #-------------------------------------------------------------------------------
 from __future__ import absolute_import, division, print_function
 
+import sys, zmq, subprocess, time, traceback, zlib, io, os, math, os.path
+if sys.version_info[0] < 3:
+  print("HKLviewer GUI must be run from Python 3")
+  sys.exit(-42)
+
 from PySide2.QtCore import Qt, QEvent, QItemSelectionModel, QSize, QSettings, QTimer
 from PySide2.QtWidgets import (  QAction, QCheckBox, QComboBox, QDialog,
         QFileDialog, QGridLayout, QGroupBox, QHeaderView, QHBoxLayout, QLabel, QLineEdit,
@@ -20,8 +25,6 @@ from PySide2.QtWidgets import (  QAction, QCheckBox, QComboBox, QDialog,
 
 from PySide2.QtGui import QColor, QFont, QCursor, QDesktopServices
 from PySide2.QtWebEngineWidgets import ( QWebEngineView, QWebEngineProfile, QWebEnginePage )
-import sys, zmq, subprocess, time, traceback, zlib, io, os, math, os.path
-
 
 try: # if invoked by cctbx.python or some such
   from crys3d.hklview import HKLviewerGui
@@ -69,20 +72,9 @@ class AboutForm(QDialog):
     mainLayout = QGridLayout()
     self.aboutlabel = QLabel()
     self.aboutlabel.setWordWrap(True)
-    aboutstr = """<html><head/><body><p><span style=" font-weight:600;">
-    HKLviewer, </span>A reflection data viewer for crystallography
-    <br/>Developers: Dr. Robert D. Oeffner<br/>
-    Cambridge Institute for Medical Research, University of Cambridge.<br/>
-    HKLviewer is part of the <a href="http://cci.lbl.gov/docs/cctbx/"> CCTBX library</a>
-    as well as derived software thereof.<br/>
-    HKLviewer uses functionality provided by the
-    <a href="https://github.com/nglviewer/ngl">NGL Viewer</a> project and
-    the <a href="https://github.com/niklasvh/html2canvas">html2canvas</a> project.
-    Refer to rdo20@cam.ac.uk or cctbx@cci.lbl.gov for queries or bug reports.
-    </p></body></html>"""
-    self.aboutlabel.setText(aboutstr)
     self.aboutlabel.setTextInteractionFlags(Qt.TextBrowserInteraction);
     self.aboutlabel.setOpenExternalLinks(True);
+    self.writeAboutstr("")
     self.copyrightstxt = QTextEdit()
     self.copyrightstxt.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
     self.copyrightstxt.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
@@ -99,6 +91,22 @@ class AboutForm(QDialog):
     self.setLayout(mainLayout)
     self.setMinimumSize(QSize(350, 200))
     self.setFixedSize( self.sizeHint() )
+  def writeAboutstr(self, versionstr):
+    aboutstr = """<html><head/><body><p>
+    <span style=" font-weight:600;">HKLviewer, </span>
+    CCTBX version: """ + versionstr + \
+    """
+    <br/>A reflection data viewer for crystallography
+    <br/>Developers: Dr. Robert D. Oeffner<br/>
+    Cambridge Institute for Medical Research, University of Cambridge.<br/>
+    HKLviewer is part of the <a href="http://cci.lbl.gov/docs/cctbx/"> CCTBX library</a>
+    as well as derived software thereof.<br/>
+    HKLviewer uses functionality provided by the
+    <a href="https://github.com/nglviewer/ngl">NGL Viewer</a> project and
+    the <a href="https://github.com/niklasvh/html2canvas">html2canvas</a> project.
+    Refer to rdo20@cam.ac.uk or cctbx@cci.lbl.gov for queries or bug reports.
+    </p></body></html>"""
+    self.aboutlabel.setText(aboutstr)
   def onOK(self):
     self.hide()
 
@@ -147,7 +155,7 @@ class WebEngineDebugForm(QDialog):
                         Qt.WindowTitleHint |
                         Qt.WindowSystemMenuHint
                         )
-    self.setWindowTitle("Chrome QWebEngineDebug")
+    self.setWindowTitle("Chromium QWebEngineDebug")
     browser = QWebEngineView()
     mainLayout = QGridLayout()
     mainLayout.addWidget(browser, 0, 0)
@@ -275,7 +283,7 @@ class NGL_HKLViewer(HKLviewerGui.Ui_MainWindow):
     self.MillerLabel3 = QLabel()
     self.MillerLabel3.setText("""<html><head/><body><p>
     For examples on creating a dataset from existing ones see
-    <a href="http://cci.lbl.gov/docs/cctbx/doc_hklviewer/#make_new_dataset">Making new dataset</a>.
+    <a href="http://cci.lbl.gov/docs/cctbx/doc_hklviewer/#making-a-new-dataset">Making a new dataset</a>.
     <br>
     For details on python scripting cctbx.miller.array see
     <a href="https://cctbx.github.io/cctbx/cctbx.miller.html#the-miller-array">cctbx.miller arrays</a>.
@@ -371,6 +379,7 @@ newarray._sigmas = sigs
     self.window.statusBar().addPermanentWidget(self.Statusbartxtbox, 1)
     self.actionOpen_reflection_file.triggered.connect(self.onOpenReflectionFile)
     self.actionLocal_Help.triggered.connect(self.onOpenHelpFile)
+    self.actionHKLviewer_Tutorial.triggered.connect(self.onOpenTutorialHelpFile)
     self.actionCCTBXwebsite.triggered.connect(self.onOpenCCTBXwebsite)
     self.actiondebug.triggered.connect(self.DebugInteractively)
     self.actionSave_Current_Image.triggered.connect(self.onSaveImage)
@@ -387,6 +396,10 @@ newarray._sigmas = sigs
     QDesktopServices.openUrl("http://cci.lbl.gov/docs/cctbx/doc_hklviewer/")
 
 
+  def onOpenTutorialHelpFile(self):
+    QDesktopServices.openUrl("http://cci.lbl.gov/docs/cctbx/tuto_hklviewer/")
+
+
   def onOpenCCTBXwebsite(self):
     QDesktopServices.openUrl("http://cci.lbl.gov/docs/cctbx/")
 
@@ -462,7 +475,7 @@ newarray._sigmas = sigs
     options = QFileDialog.Options()
     fileName, filtr = QFileDialog.getOpenFileName(self.window,
             "Open a reflection file", "",
-            "MTZ Files (*.mtz);;HKL Files (*.hkl);;CIF Files (*.cif);;SCA Files (*.sca);;All Files (*)", "", options)
+            "MTZ Files (*.mtz);;CIF Files (*.cif);;HKL Files (*.hkl);;SCA Files (*.sca);;All Files (*)", "", options)
     if fileName:
       #self.HKLnameedit.setText(fileName)
       self.window.setWindowTitle("HKLviewer: " + fileName)
@@ -472,6 +485,7 @@ newarray._sigmas = sigs
       self.send_message('openfilename = "%s"' %fileName )
       self.MillerComboBox.clear()
       self.BinDataComboBox.clear()
+      self.millertable.clearContents()
       self.tncsvec = []
       #self.ClipPlaneChkGroupBox.setChecked(False)
       self.expandP1checkbox.setChecked(False)
@@ -569,6 +583,8 @@ viewer.color_powscale = %s""" %(selcolmap, colourpowscale) )
                 txts = txts + "\n" + "#" * 50  + "\n"
             self.aboutform.copyrightstxt.setText(txts)
             self.aboutform.setFixedSize( self.aboutform.sizeHint() )
+          if self.infodict.get("cctbxversion"):
+            self.aboutform.writeAboutstr( self.infodict["cctbxversion"])
 
           if self.infodict.get("scene_array_label_types"):
             self.scenearraylabeltypes = self.infodict.get("scene_array_label_types", [])
@@ -1582,7 +1598,10 @@ viewer.color_powscale = %s""" %(selcolmap, colourpowscale) )
       for i,r in enumerate(self.millertable.selectedrows):
         labels.extend( self.millerarraylabels[r].split(",") ) # to cope with I,SigI or other multiple labels
       myqa = QAction("Show a table of the %s dataset ..." %  " and ".join(labels), self.window, triggered=self.testaction)
-      myqa.setData( ("tabulate_data", labels ))
+      lbls =[] # group any crystal_id=1, wavelength_id, scale_group_code with labels in lists
+      for i,r in enumerate(self.millertable.selectedrows):
+        lbls.extend( [ self.millerarraylabels[r].split(",") ] ) # to cope with I,SigI or other multiple labels
+      myqa.setData( ("tabulate_data", lbls ))
       self.millertablemenu.addAction(myqa)
     #import code, traceback; code.interact(local=locals(), banner="".join( traceback.format_stack(limit=10) ) )
     self.millertablemenu.exec_(QCursor.pos())
